<?php

/**
 * @file
 * API documentation for CINC.
 */

/**
 * This is the current target API format for the CINC module.
 * The overall goal is to closely match the D8 config API, but with additional
 * functionality, e.g. ->add_field().
 *
 * The work being done right now on CINC is in effort to get this file to work.
 * As more work is done, this file and the CINC API may change.
 */

function example_enable() {

  /**
   * Create content types.
   */

  $blog_post = CINC::config('ContentType')
    ->set('type', 'example_blog_post')
    ->set('name', 'Blog Post');
    ->set('description', 'A blog post for writing blogs and what not')
    ->create();

  $event = CINC::config('ContentType')
    ->set('type', 'example_event')
    ->set('name', 'Event')
    ->create();

  /**
   * Create fields.
   */

  $subtitle = CINC::config('FieldText')
    ->set('field_name', $blog_post->machine_name . '_subtitle')
    ->set('label', 'Subtitle')
    ->create();

  $blog_post->add_field($subtitle);

  $custom_teaser = CINC::config('FieldLongText')
    ->set('field_name', $blog_post->machine_name . '_teaser')
    ->set('label', 'Custom Teaser');
    ->create();

  $blog_post->add_field($custom_teaser);

  $related_event = CINC::config('FieldEntityReference')
    ->set('field_name', $blog_post->machine_name . '_event')
    ->set('label', 'Related Event')
    ->widget('inline entity')
    ->references('example_event')
    ->create();

  $blog_post->add_field($related_event);

  $date = CINC::config('FieldDate')
    ->set('field_name', $event->machine_name . '_date')
    ->set('label', 'Date')
    ->widget('pop-up calender')
    ->collect('year')
    ->create();

  $event->add_field($date);

}

/**
 * Example YAML representation of the same config above.
 * This needs some settings examples.
 */

/config/install/node.type.example_blog_post.yml:

type: example_blog_post
label: Blog Post

/config/install/node.type.example_event.yml:

type: example_event
label: Event

/config/install/field.example_blog_post_subtitle.yml

label: Subtitle
type: text
node_bundles: [example_blog_post]

/config/install/field.example_blog_post_teaser.yml

label: Custom Teaser
type: long text
node_bundles: [example_blog_post]

/config/install/field.example_blog_post_event.yml

label: Related Event
type: entity reference
widget: inline entity
references: [example_event]
node_bundles: [example_blog_post]

/config/install/field.example_event_date.yml

label: Date
widget: pop-up calendar
collect: year
node_bundles: [example_event]

/**
 * Target Drush interface for adding same config above.
 * Not sure yet how this should handle nested settings arrays.
 */

$ drush cinc-ct example_blog_post "Blog Post"
$ drush cinc-ct example_event Event
$ drush cinc-f-text example_blog_post_subtitle --label=Subtitle --add-to=example_blog_post
$ drush cinc-f-longtext example_blog_post_teaser --label="Custom Teaser" --add-to=example_blog_post
$ drush cinc-f-entityref example_blog_post_event --label="Related Event" --add-to=example_blog_post
$ drush cinc-f-date example_event_date --label=Date --add-to=example_event


