<?php

/**
 * Creates contexts in code.
 *
 * @code
 * $context = CINC::init('Context')->set('name', 'my_context');
 * @endcode
 */
class CINC_Context extends CINC implements CINC_CRUD {

  function __construct() {

    $this->config_filters['name'] = 'set_name';

    $this->config = array(
      'name' => '',
      'tag' => '',
      'description' => '',
      'conditions' => array(),
      'reactions' => array(),
      'condition_mode' => 1,
      'table' => 'context',
      'type' => 'Normal',
      'export_type' => 1,
    );

  }

  /**
   * Cleans name.
   */
  public function set_name($name) {
    return CINC::clean_machine_name($name);
  }

  /**
   * Saves context to the database.
   */
  public function create() {
    $context = (object) $this->config;
    context_save($context);
    $this->read();
    return $this;
  }

  /**
   * Loads context from the database.
   */
  public function read() {
    $this->config = (array) context_load($this->config['name']);
    return $this;
  }

  /**
   * Saves context to the database.
   */
  public function update() {
    $this->create();
    return $this;
  }

  /**
   * Removes context from the database.
   */
  public function delete() {
    $context = (object) $this->config;
    context_delete($context);
    return $this;
  }

  public function add_node_condition($types, $node_form = FALSE) {
    $values = array();

    foreach ($types as $type) {
      $values[$type] = $type;
    }

    $this->set('conditions', array(
      'node' => array(
        'values' => $values,
        'options' => array(
          'node_form' => (int) $node_form,
        ),
      ),
    ));

    return $this;
  }

  public function add_global_condition() {
    $this->set('conditions', array(
      'sitewide' => array(
        'values' => array(1 => 1),
      ),
    ));

    return $this;
  }

  public function add_path_condition($paths) {
    $values = array();

    foreach ($paths as $path) {
      $values[$path] = $path;
    }

    $this->set('conditions', array(
      'path' => array(
        'values' => $values,
      ),
    ));

    return $this;
  }


  public function add_block_reaction($module, $delta, $region, $weight = 0) {

    $block_id = $module . '-' . $delta;

    $this->set('reactions', array(
      'block' => array(
        'blocks' => array(
          $block_id => array(
            'module' => $module,
            'delta' => $delta,
            'region' => $region,
            'weight' => $weight,
          ),
        ),
      ),
    ));

    return $this;

  }

  public function disable() {

    $status = variable_get('context_status', array());
    $status[$this->config['name']] = TRUE;
    variable_set('context_status', $status);

    $this->read();
    return $this;

  }

}
