<?php

/**
 * Creates field groups in code.
 *
 * @code
 * $field_group = CINC::init('FieldGroup')->set('group_name', 'my_content_type');
 * @endcode
 */
class CINC_FieldGroup extends CINC implements CINC_CRUD {

  public static $groups = array();

  function __construct() {

    $this->config_filters['group_name'] = 'set_group_name';
    $this->config_filters['entity_type'] = 'set_entity_type';
    $this->config_filters['bundle'] = 'set_bundle';
    $this->config_filters['mode'] = 'set_mode';

  	$this->config = array(
			'identifier' => '',
			'group_name' => '',
			'entity_type' => 'node',
			'bundle' => '',
			'mode' => 'form',
			'parent_name' => '',
			'table' => 'field_group',
			'type' => 'Normal',
			'disabled' => false,
			'label' => '',
			'weight' => '0',
			'children' => array(),
			'format_type' => 'div',
			'format_settings' => array(
    		'formatter' => 'open',
    		'instance_settings' => array(
    		  'description' => '',
    		  'show_label' => 0,
    		  'label_element' => 'h3',
    		  'effect' => 'none',
    		  'speed' => 'fast',
    		  'classes' => '',
    		),
    	),
		);

  }

  /**
   * Auto-adds label when group_name is set, cleans group_name and updates identifier.
   */
  public function set_group_name($group_name) {
    $clean = CINC::clean_machine_name($group_name);
    if (empty($this->config['label'])) {
      $this->set('label', CINC::display_name_from_machine_name($clean));
    }
    $this->set('identifier', implode('|', array($clean, $this->config['entity_type'], $this->config['bundle'], $this->config['mode'])));
    return $clean;
  }

  /**
   * Updates identifier.
   */
  public function set_entity_type($entity_type) {
    $this->set('identifier', implode('|', array($this->config['group_name'], $entity_type, $this->config['bundle'], $this->config['mode'])));
    return $entity_type;
  }

  /**
   * Updates identifier.
   */
  public function set_bundle($bundle) {
    $this->set('identifier', implode('|', array($this->config['group_name'], $this->config['entity_type'], $bundle, $this->config['mode'])));
    return $bundle;
  }

  /**
   * Updates identifier.
   */
  public function set_mode($mode) {
    $this->set('identifier', implode('|', array($this->config['group_name'], $this->config['entity_type'], $this->config['bundle'], $mode)));
    return $mode;
  }

  /**
   * Saves field group to the database.
   */
  public function create() {
    $group = (object) $this->config;
		field_group_group_save($group);

    return $this;
  }

  /**
   * Loads field group from the database.
   */
  public function read() {

    if (empty(CINC_FieldGroup::$groups)) {
      CINC_FieldGroup::$groups = field_group_read_groups();
    }

    $bundle = CINC_FieldGroup::$groups[$this->config['entity_type']][$this->config['bundle']];
    $this->config = (array) $bundle[$this->config['mode']][$this->config['group_name']];

    return $this;
  }

  /**
   * Saves field group to the database and migrates previous data if machine name changed.
   */
  public function update() {
    $this->create();

    return $this;
  }

  /**
   * Removes field group from the database.
   */
  public function delete() {
    $group = (object) $this->config;
    field_group_group_export_delete($group);

    return $this;
  }

  /**
   * Add fields to the field group.
   *
   * @param stdClass $field_instance
   *   An instance of a CINC_Field[type]
   * @return $this
   */
  public function add_field($field) {
    if (!($field instanceof CINC_Field)) {
      throw new Exception('CINC_FieldGroup::add_field requires a CINC_Field instance as the first parameter');
    }

    $children =& $this->config['children'];

    if (!in_array($field->config['field_name'], $children)) {
      $children[] = $field->config['field_name'];
    }

    return $this;
  }

}
