<?php

/**
 * Creates image styles in code.
 *
 * @code
 * $my_image_style = CINC::init('ImageStyle')->set('name', 'my_image_style');
 * @endcode
 */
class CINC_ImageStyle extends CINC implements CINC_CRUD {

  function __construct() {

    $this->config_filters['name'] = 'set_name';

    $this->config = array(
      'name' => '',
      'label' => '',
      'effects' => array(),
    );

  }

  /**
   * Auto-adds label when name is set, and cleans name.
   */
  public function set_name($name) {
    if (empty($this->config['label'])) {
      $this->set('label', CINC::display_name_from_machine_name($name));
    }
    return CINC::clean_machine_name($name);
  }

  /**
   * Saves image style to the database.
   */
  public function create() {
    $this->config = image_style_save($this->config);
    return $this;
  }

  /**
   * Loads image style from the database.
   */
  public function read() {
    $this->config = image_style_load($this->config['name']);
    return $this;
  }

  /**
   * Saves image style to the database.
   */
  public function update() {
    $this->create();
    return $this;
  }

  /**
   * Removes image style from the database.
   */
  public function delete() {
    if (empty($this->config['isid'])) {
      $this->read();
    }
    image_style_delete($this->config, $replacement);
    return $this;
  }

  public function add_effect($effect) {
    $effect->add_to_style($this);
    $this->config['effects'][$effect->effect['ieid']] = $effect;
    return $this;
  }

}

/**
 * Creates image effects in code.
 *
 * @code
 * $my_image_effect = CINC::init('ImageEffect')->set('name', 'my_image_effect');
 * @endcode
 */
class CINC_ImageEffect extends CINC implements CINC_CRUD {

  function __construct() {

    $this->config_filters['name'] = 'set_name';

    $this->config = array(
      'name' => '',
      'weight' => 1,
      'data' => array()
    );

  }

  /**
   * Cleans name.
   */
  public function set_name($name) {
    return CINC::clean_machine_name($name);
  }

  /**
   * Saves image style to the database.
   */
  public function create() {
    $this->config = image_effect_save($this->config);
    return $this;
  }

  /**
   * Loads image style from the database.
   */
  public function read() {
    $this->config = image_effect_load($this->config['ieid'], $this->config['name']);
    return $this;
  }

  /**
   * Saves image style to the database.
   */
  public function update() {
    $this->create();
    return $this;
  }

  /**
   * Removes image style from the database.
   */
  public function delete() {
    image_effect_delete($this->config);
    return $this;
  }

  public function add_to_style($style) {
    $this->config['isid'] = $style->config['isid'];
    return $this;
  }

}