<?php

/**
 * Creates menus in code.
 *
 * @code
 * $menu = CINC::init('Menu')->set('menu_name', 'my_menu');
 * @endcode
 */
class CINC_Menu extends CINC implements CINC_CRUD {

  public $links = array();

  function __construct($machine_name, $title = '') {

    $this->config_filters['menu_name'] = 'set_menu_name';

  	$this->config = array(
      'menu_name' => '',
      'title' => '',
      'description' => '',
		);

  }

  /**
   * Auto-adds name when type is set, and cleans type.
   */
  public function set_menu_name($menu_name) {
    if (empty($this->config['title'])) {
      $this->set('title', CINC::display_name_from_machine_name($menu_name));
    }
    return CINC::clean_machine_name($menu_name);
  }

  /**
   * Saves menu to the database.
   */
  public function create() {
    menu_save($this->config);
    return $this;
  }

  /**
   * Loads menu from the database.
   */
  public function read() {
    $this->config = menu_load($this->config['menu_name']);
    $this->links = menu_load_links($this->config['menu_name']);
    return $this;
  }

  public function get_links_as_tree() {
    return menu_tree_data($this->links);
  }

  public function get_link_by_property($property, $value) {

    foreach ($this->links as $link) {
      if ($link[$property] == $value) {
        return $link;
      }
    }

  }

  /**
   * Saves menu to the database and migrates previous data if machine name changed.
   */
  public function update() {
    $this->create();
    return $this;
  }

  /**
   * Removes menu from the database.
   */
  public function delete() {
    menu_delete($this->config);
    return $this;
  }

}
